
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude">

  <xi:include href="master.html" />

<head>
  <meta content="text/html; charset=UTF-8" http-equiv="Content-Type" py:if="False"/>
  <title>Articles</title>
  <link rel="stylesheet" type="text/css" media="screen" href="${tg.url('/_pluggable/smallpress/css/style.css')}" />
</head>

<body>
    <div id="smallpress_rightbar">
        ${h.call_partial('smallpress.partials:search')}
        ${h.call_partial('smallpress.partials:tagcloud', tags=tags)}
    </div>
    <div id="smallpress_articles_box">
        <div py:if="request.identity and 'smallpress' in request.identity['groups']">
            <a href="${h.plug_url('smallpress', '/manage/'+blog)}">manage articles</a>
        </div>
        <div>${h.call_partial('smallpress.partials:articles', articles=articles)}</div>
    </div>
    <div style="clear:right;"></div>
</body>
</html>
