<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
        "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude"
      itemscope="itemscope" itemtype="http://schema.org/Article">

<xi:include href="master.html" />

<head>
    <title>Articles</title>
    <link rel="stylesheet" type="text/css" media="screen" href="${tg.url('/_pluggable/smallpress/css/style.css')}" />
    <meta name="description" content="${article.description}" />
    <meta property="og:title" content="${article.title}" />
    <meta property="og:description" content="${article.description}" />
    <meta itemprop="name" content="${article.title}" />
    <meta itemprop="description" content="${article.description}" />
</head>

<body>
    <div id="smallpress_rightbar">
        ${h.call_partial('smallpress.partials:search')}
        ${h.call_partial('smallpress.partials:tagcloud')}
    </div>
    <div id="smallpress_articles_box">
        <div>${h.call_partial('smallpress.partials:article_preview', article=article)}</div>
    </div>
    <div style="clear:right;"></div>
</body>
</html>
