.smallpress form ul {
    list-style: none;
    padding-left: 10px;
}

.smallpress input, .smallpress textarea {
    border: 1px solid #CCC;
    padding: 5px;
}

.smallpress input {
    width: 600px;
}

.smallpress form label {
    color: #555;
    width: 80px;
    display: inline-block;
}

.smallpress form textarea {
    width: 635px;
    min-height: 400px;
}

.smallpress form #title {
    font-weight: bold;
}

.smallpress form #content {
    padding: 0;
    margin: 0;
}

.smallpress #submit_container {
    width: 700px;
    position: relative;
    height: 20px;
}

.smallpress .submitbutton {
    width: 100px;
    position: absolute;
    right: 0;
    cursor: pointer;
    background-color: #DDD;
}

.smallpress .submitbutton:hover {
    background-color: #BBB;
}

.smallpress #file {
    border: none;
}

.smallpress_buttons a img {
    width: 24px;
    border: none;
}

.smallpress_buttons a {
    text-decoration: none;
}

#smallpress_create_box {
    border: 1px solid #CCC;
    background-color: #F0F0F0;
    margin-top: 4px;
    margin-bottom: 4px;
    padding: 5px;
}

#smallpress_create_box h1 {
    margin: 0;
}

.smallpress_text_button {
    border: 1px solid #CCC;
    padding: 5px;
    float: right;
    border-radius: 4px;
    background-color: #DDD;
}

.smallpress_text_button a {
    text-decoration: none;
    color: black;
    font-weight: bold;
    display: block;
}

.smallpress_text_button:hover {
    background-color: #BBB;
}

#smallpress_attachments {
    margin-top: 50px;
    width: 710px;
}

#attachments_table {
    padding-left: 10px;
}

#attachments_table a {
    color: blue;
}

#attachments_table a:hover {
    text-decoration: underline;
}

#smallpress_articles_box {
    width: 67%;
    margin-right: 3%;
}

#smallpress_rightbar {
    width: 30%;
    float: right;
}

#smallpress_rightbar h3 {
    font: bold 12px Verdana, Tahoma, sans-serif;
    background-color: #F0F0F0;
    border-bottom: medium none;
    border-top: 1px solid #CCC;
    padding: 2px;
    padding-left: 5px;
}

.smallpress_article h2 {
    font: bold 20px/24px Georgia, "Times New Roman", Times, serif;
    background-color: #F0F0F0;
    border-bottom: medium none;
    border-top: 1px solid #CCC;
    padding: 2px;
    padding-left: 5px;
}

.smallpress_article h4 {
    color: #999;
    font: 11px/11px Verdana, Tahoma, sans-serif;
}

.smallpress_article_content {
    font: 11px/18px Verdana, Tahoma, sans-serif;
    color: #606060;
}

#smallpress_tags .tagcloud {
    font-size: 12px;
}

.smallpress_article h2 a {
    text-decoration: none;
    color: black;
}

#smallpress_search #text_container {
    float: left;
}

#smallpress_search ul {
    list-style: none;
    padding-left: 10px;
}

#smallpress_search .textfield {
    border: 1px solid #CCC;
    padding: 2px;
}

#smallpress_search .submitbutton {
    border: 1px solid #CCC;
    background-color: #DDD;
    cursor: pointer;
}

#smallpress_search .submitbutton:hover {
    background-color: #BBB;
}

.smallpress_attachment_minipreview {
    height: 64px;
}

#smallpress_attachments_title {
    margin-bottom: 10px;
}

#smallpress_attachments_title span {
    font-size: 1.6em;
}

#smallpress_attachments_title em {
    margin-left: 10px;
    font-size: 11px;
}