<div xmlns:py="http://genshi.edgewall.org/" id="smallpress_articles_excerpts">
    <py:for each="article in articles">
        ${h.call_partial('smallpress.partials:excerpt', article=article)}
    </py:for>
</div>
