<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
        "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/"
      xmlns:xi="http://www.w3.org/2001/XInclude">

<xi:include href="master.html" />

<head>
    <meta content="text/html; charset=UTF-8" http-equiv="Content-Type" py:if="False"/>
    <title>New Article</title>
    <link rel="stylesheet" type="text/css" media="screen" href="${tg.url('/_pluggable/smallpress/css/style.css')}" />
</head>

<body>
<div id="smallpress_manage" class="smallpress">
    <div id="smallpress_create_box">
        <div class="smallpress_text_button">
            <a href="${tg.url(create_action)}">Write New Article</a>
        </div>
        <h1>Articles</h1>
    </div>
    ${table.display(articles)}
    <div>
        ${tmpl_context.paginators.articles.pager()}
    </div>
</div>
</body>
</html>
