<div xmlns:py="http://genshi.edgewall.org/" class="smallpress_article">
    <h2>
        <a href="${h.plug_url('smallpress', '/view/%s'%article.uid)}">${article.title}</a>
    </h2>
    <h4>
        <span py:if="article.is_owner(request.identity)">
            <a href="${h.plug_url('smallpress', '/edit/%s'%article.uid)}">edit</a> |
        </span>
        ${article.author} | ${h.smallpress.format_date(article)} | ${h.smallpress.comma_separated_tags(article)}
    </h4>
    <div class="smallpress_article_content">
        ${Markup(article.content)}
    </div>
</div>
