<html xmlns:py="http://genshi.edgewall.org/"
      py:strip="">
<body>
<div id="attachments_table">
    ${table.display(attachments)}
</div>
<div id="${ajaxform_id}">
    ${ajaxform._ajaxform_display(value=value)}
</div>
<script>
if (typeof jQuery != 'undefined') {
    jQuery('#${ajaxform_id}').find('form').ajaxForm({target:jQuery('#${ajaxform_id}').parent(),
        url:'${ajaxform_action}',
        beforeSubmit:function(arr, form, options) {
            jQuery('#${ajaxform_id}').find('form').hide();
            jQuery('#${ajaxform_id}').append('<img class="spinner_icon" src="${ajaxform_spinner.link}"/>');
        }
    });
}
</script>
</body>
</html>
